from setuptools import setup

setup(name='jie',
      version='1.0.0',
      py_modules=['series'],
      description='递归法实现斐波那契数列',
      author='zj-1225',
      author_email='3183631339@qq.com',
      license='MIT',
      keywords='helper',
      install_requires=['scapy>=2.4.4','psutil>=5.8.0'],
      python_requires='>=3'),

